@@ -70,7 +70,7 @@ static GtkTreeView *setup_make_view(PersonalMenuSetup *setup)
 	gboolean fileExists;
 	GKeyFile* keyFile;
 
-	setup->entryList=gtk_list_store_new(9,GDK_TYPE_PIXBUF,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_BOOLEAN,G_TYPE_INT);
+	setup->entryList=gtk_list_store_new(7,GDK_TYPE_PIXBUF,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING);
 	/*setup->entryList=gtk_list_store_new(4,GDK_TYPE_PIXBUF,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING);*/
 
 	keyFile=g_key_file_new();
@@ -106,24 +106,21 @@ static GtkTreeView *setup_make_view(PersonalMenuSetup *setup)
 		runInTerm="false";
 	    service=g_key_file_get_string(keyFile,entry,"service",NULL);
 
-		if (executable!=NULL && g_strcasecmp(executable,"")!=0)
-		{
-			icon_theme = gtk_icon_theme_get_default ();
-			icon=gtk_icon_theme_load_icon(icon_theme,iconName,40,0,NULL);
-			if (icon==NULL)
-			{
-			  icon=gtk_icon_theme_load_icon(icon_theme,"qgn_list_gene_default_app",40,0,NULL);
-			}
-			icon=gdk_pixbuf_scale_simple(icon,40,40,GDK_INTERP_NEAREST);
-		}
+	    icon_theme = gtk_icon_theme_get_default ();
+	    icon=gtk_icon_theme_load_icon(icon_theme,iconName,40,0,NULL);
+	    if (icon==NULL)
+	    {
+	      icon=gtk_icon_theme_load_icon(icon_theme,"qgn_list_gene_default_app",40,0,NULL);
+	    }
+	    icon=gdk_pixbuf_scale_simple(icon,40,40,GDK_INTERP_NEAREST);
 	    gtk_list_store_append(setup->entryList, &setup->entryIter);
 	    if (executable==NULL || g_strcasecmp(executable,"")==0)
 	    {
-	    	gtk_list_store_set(setup->entryList, &setup->entryIter,1,appName,2,executable,3,iconName,4,runAsRoot,5,runInTerm,6,service,7,TRUE,8,800,-1);
+	    	gtk_list_store_set(setup->entryList, &setup->entryIter,1,appName,2,executable,3,iconName,4,runAsRoot,5,runInTerm,6,service,-1);
 	    }
 	    else
 	    {
-	    	gtk_list_store_set(setup->entryList, &setup->entryIter, 0, icon,1,appName,2,executable,3,iconName,4,runAsRoot,5,runInTerm,6,service,7,FALSE,-1);
+	    	gtk_list_store_set(setup->entryList, &setup->entryIter, 0, icon,1,appName,2,executable,3,iconName,4,runAsRoot,5,runInTerm,6,service,-1);
 	    }
 	    /*gtk_list_store_set(setup->entryList, &setup->entryIter, 0, icon,1,appName,2,executable,3,iconName,-1);*/
 	    g_object_unref(G_OBJECT(icon));
@@ -136,9 +133,7 @@ static GtkTreeView *setup_make_view(PersonalMenuSetup *setup)
 
 	res = GTK_TREE_VIEW(gtk_tree_view_new_with_model(GTK_TREE_MODEL(setup->entryList)));
 	gtk_tree_view_append_column(res,gtk_tree_view_column_new_with_attributes(NULL,gtk_cell_renderer_pixbuf_new(),"pixbuf",0,NULL));
-	gtk_tree_view_append_column(res,gtk_tree_view_column_new_with_attributes(NULL,gtk_cell_renderer_text_new(),"text",1,"weight-set",7,"weight",8,NULL));
-	
-	
+	gtk_tree_view_append_column(res,gtk_tree_view_column_new_with_attributes(NULL,gtk_cell_renderer_text_new(),"text",1,NULL));
 	//gtk_tree_view_append_column(res,gtk_tree_view_column_new_with_attributes(NULL,gtk_cell_renderer_text_new(),"text",2,NULL));
 	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(res),GTK_SELECTION_BROWSE);
 
@@ -206,6 +201,7 @@ void desktop_select_activate(GtkIconView *iconView, GtkTreePath *path, PersonalM
 
 void select_desktop_file(GtkButton *button, PersonalMenuSetup *setup)
 {
+	GtkDialog *dialog;
 	DIR *d;
 	struct dirent *dir;
 	GtkListStore *store;
@@ -231,7 +227,6 @@ void select_desktop_file(GtkButton *button, PersonalMenuSetup *setup)
 	gtk_dialog_add_action_widget(GTK_DIALOG(setup->selectDialog), gtk_button_new_with_label("Cancel"), GTK_RESPONSE_REJECT);
 
 	store=gtk_list_store_new(6,GDK_TYPE_PIXBUF,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING);
-	
 	d=opendir("/usr/share/applications/hildon/");
 	if (d)
 	{
@@ -259,7 +254,7 @@ void select_desktop_file(GtkButton *button, PersonalMenuSetup *setup)
 				{
 				  icon=gtk_icon_theme_load_icon(icon_theme,"qgn_list_gene_default_app",64,0,NULL);
 				}
-				//icon=gdk_pixbuf_scale_simple(icon,64,64,GDK_INTERP_NEAsetup->iconViewT);
+				//icon=gdk_pixbuf_scale_simple(icon,64,64,GDK_INTERP_NEAREST);
 				if (strlen(gettext(appName))>15)
 				{
 					char ell[3]="...";
@@ -271,7 +266,7 @@ void select_desktop_file(GtkButton *button, PersonalMenuSetup *setup)
 					strncat(shortName,gettext(appName),15);
 				}
 				gtk_list_store_append(store, &iter);
-				gtk_list_store_set(store, &iter,0,icon,1,gettext(appName),2,executable,3,iconName,4,service,5,g_strconcat("<small>",shortName,"</small>",NULL),-1);
+				gtk_list_store_set(store, &iter,0,icon,1,gettext(appName),2,executable,3,iconName,4,service,5,shortName,-1);
 				g_object_unref(G_OBJECT(icon));
 			}
 		}
@@ -279,8 +274,7 @@ void select_desktop_file(GtkButton *button, PersonalMenuSetup *setup)
 	g_key_file_free(keyFile);
     
 	setup->iconView=gtk_icon_view_new();
-	gtk_icon_view_set_text_column(GTK_ICON_VIEW(setup->iconView),1);
-	gtk_icon_view_set_markup_column(GTK_ICON_VIEW(setup->iconView),5);
+	gtk_icon_view_set_text_column(GTK_ICON_VIEW(setup->iconView),5);
 	gtk_icon_view_set_pixbuf_column(GTK_ICON_VIEW(setup->iconView),0);
 	gtk_icon_view_set_columns(GTK_ICON_VIEW(setup->iconView),3);
 	gtk_icon_view_set_selection_mode(GTK_ICON_VIEW(setup->iconView),GTK_SELECTION_BROWSE);
@@ -293,7 +287,7 @@ void select_desktop_file(GtkButton *button, PersonalMenuSetup *setup)
 	
 	scroll = gtk_scrolled_window_new(NULL, GTK_ADJUSTMENT(gtk_adjustment_new(0, 0, 25, 0, 0, 0)));
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
-	gtk_widget_set_size_request(GTK_WIDGET(scroll), 480, 265);
+	gtk_widget_set_size_request(GTK_WIDGET(scroll), 600, 265);
 	gtk_container_add(GTK_CONTAINER(scroll), GTK_WIDGET(setup->iconView));
 
 	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(setup->selectDialog)->vbox), scroll);
@@ -363,6 +357,7 @@ void icon_select_activate(GtkIconView *iconView, GtkTreePath *path, PersonalMenu
 
 void select_icon(GtkButton *button, PersonalMenuSetup *setup)
 {
+	GtkDialog *dialog;
 	GtkIconTheme *iconTheme;
 	GList *iconList;
 	GtkListStore *store;
@@ -444,7 +439,6 @@ void select_icon(GtkButton *button, PersonalMenuSetup *setup)
 
 	gtk_box_pack_start(GTK_BOX(vbox),scroll,FALSE,FALSE,0);
 	setup->nameLabel=gtk_label_new("Icon name");
-	gtk_label_set_ellipsize(GTK_LABEL(setup->nameLabel),PANGO_ELLIPSIZE_END);
 	gtk_misc_set_alignment(GTK_MISC(setup->nameLabel),0,0.5);
 	caption=hildon_caption_new(NULL,"Icon name",setup->nameLabel,NULL,HILDON_CAPTION_MANDATORY);
 	gtk_box_pack_start(GTK_BOX(vbox),caption,FALSE,FALSE,0);
@@ -527,7 +521,7 @@ static void dialog_add_edit(GtkTreeIter iter, gboolean edit, PersonalMenuSetup *
 		gchar *appName,*iconName,*executable;
 		gchar *runAsRoot,*runInTerm;
 		gtk_tree_model_get(gtk_tree_view_get_model(setup->view),&iter,1,&appName,2,&executable,3,&iconName,4,&runAsRoot,5,&runInTerm,-1);
-		/*gtk_tree_model_get(gtk_tree_view_get_model(setup->view),&iter,1,&appName,2,&executable,3,&iconName,-1);*/
+		setup->entryIter=iter;	/*gtk_tree_model_get(gtk_tree_view_get_model(setup->view),&iter,1,&appName,2,&executable,3,&iconName,-1);*/
 		gtk_entry_set_text(GTK_ENTRY(appNameEntry),appName);
 		gtk_image_set_from_icon_name(GTK_IMAGE(setup->iconPreview),iconName,GTK_ICON_SIZE_SMALL_TOOLBAR);
 		gtk_entry_set_text(GTK_ENTRY(executableEntry),executable);
@@ -588,11 +582,11 @@ static void dialog_add_edit(GtkTreeIter iter, gboolean edit, PersonalMenuSetup *
 
 void set_font_button_text(PersonalMenuSetup *setup, gchar *text, gboolean header)
 {
-	if (strlen(text)>34)
+	if (strlen(text)>15)
 	{
-		char result[35]="";
+		char result[16]="";
 		char ell[3]="...";
-		strncat(result,text,31);
+		strncat(result,text,12);
 		strncat(result,ell,3);
 		if (header)
 			gtk_button_set_label(GTK_BUTTON(setup->headerFontButton),result);
