@@ -325,7 +325,7 @@ static void menu_off(GtkMenu *menu, PersonalMenuNavigatorPlugin *plugin)
 }
 
 static void
-popup_menu(GtkToggleButton *button, PersonalMenuNavigatorPlugin *plugin)
+popup_menu (GtkWidget *button, PersonalMenuNavigatorPlugin *plugin)
 {
 	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(plugin->button)))
 	{
@@ -359,8 +359,6 @@ static void create_menu (PersonalMenuNavigatorPlugin *plugin)
 	gtk_widget_destroy(plugin->menu);
     plugin->menu = gtk_menu_new ();
 
-	g_object_set(plugin->menu,"background-color","red",NULL);
-
     keyFile=g_key_file_new();
     filename=g_strdup(HOME_DIR);
     filename=g_strconcat(filename,"/.personal_menu.rc",NULL);
@@ -524,9 +522,9 @@ static void create_menu (PersonalMenuNavigatorPlugin *plugin)
 		menu_item=gtk_menu_item_new_with_label(appName);
 		gtk_label_set_use_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),TRUE);
 		if (headerSystemBool)
-			gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span weight='bold'>",appName,"</span>",NULL));
+			gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span weight='bold'>",g_markup_escape_text(appName,-1),"</span>",NULL));
 		else
-			gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span font_desc='",headerFontString,"' foreground='#",headerColourString,"'>",gtk_label_get_label(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item)))),"</span>",NULL));
+			gtk_label_set_markup(GTK_LABEL(gtk_bin_get_child(GTK_BIN(menu_item))),g_strconcat("<span font_desc='",headerFontString,"' foreground='#",headerColourString,"'>",g_markup_escape_text(appName,-1),"</span>",NULL));
 		g_signal_connect(G_OBJECT(menu_item),"select",G_CALLBACK(header_select),NULL);
 		g_signal_connect(G_OBJECT(menu_item),"button-release-event",G_CALLBACK(header_activate),NULL);
 	}
@@ -661,8 +659,6 @@ personal_menu_navigator_plugin_init (PersonalMenuNavigatorPlugin *navigator_plug
   navigator_plugin->updateTimeout=0;
   navigator_plugin->popped=FALSE;
   g_signal_connect(G_OBJECT(navigator_plugin->menu),"key-release-event",G_CALLBACK(key_release),navigator_plugin);
-  
-  gtk_widget_set_extension_events(button,GDK_EXTENSION_EVENTS_ALL);
 }
 
 static void
